@@ -57,7 +57,7 @@ use Digest::MD5   ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.07';
+	$VERSION = '0.08';
 }
 
 
@@ -249,10 +249,6 @@ sub unchanged {
 
 =pod
 
-=head1 TO DO
-
-- Write Perl::Signature::Set, to handle multiple signatures
-
 =head1 SUPPORT
 
 All bugs should be filed via the CPAN bug tracker at
@@ -263,11 +259,15 @@ For other issues, or commercial enhancement or support, contact the author.
 
 =head1 AUTHORS
 
-Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>cpan@ali.asE<gt>
+
+=head1 SEE ALSO
+
+L<http://ali.as/>, L<PPI>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 - 2005 Adam Kennedy. All rights reserved.
+Copyright (c) 2004 - 2006 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
